package page;

import io.qameta.allure.Description;
import io.qameta.allure.Story;
import io.restassured.response.Response;
import org.testng.Reporter;
import org.testng.annotations.Test;
import util.JDBCUtils;

import java.util.HashMap;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import static org.testng.Assert.*;

public class DictionaryPageTest {
    DictionaryPage dictionaryPage=new DictionaryPage();

    @Test
    @Description("正常测试用例：搜索所有的词典")
    @Story("登录")
    public void passwordLoginSuccess(){
        try{
            HashMap<String,Object> body=new HashMap<>();
            body.put("_file","/apijson/page/dictionaryPage/eweiShopQaQuestionFindConditions.json");
            body.put("conditionOne","出口退税");
            Response response= dictionaryPage.findConditions(body);
            assertEquals((int)response.path("code"),200);
            assertEquals(response.path("message"),"操作成功");
            List<List<HashMap<String,String>>> title=response.path("data.children");
            title.forEach(list -> {
                list.forEach(map -> {
                    assertTrue(map.get("title").contains("出口退税"));
                });
            });
        }catch (AssertionError e){
            Reporter.log("DictionaryPageTest.passwordLoginSuccess：搜索所有的词典，断言失败！");
            throw  e;
        }
    }

    @Test
    @Description("异常测试用例：关键字为空，搜索全部政策词典")
    @Story("政策词典")
    public void keywordEmptySearchSuccess(){
        try{
            HashMap<String,Object> body=new HashMap<>();
            body.put("_file","/apijson/page/dictionaryPage/eweiShopQaQuestionFindConditions.json");
            body.put("conditionOne","");
            Response response=dictionaryPage.findConditions(body);
            assertEquals((int) response.path("code"),200);
            assertEquals(response.path("message"),"操作成功");
            assertTrue(!((List)response.path("data")).isEmpty());
        }catch (AssertionError e){
            Reporter.log("DictionaryPageTest.keywordEmptySearchSuccess：关键字为空，搜索全部政策词典，断言失败！");
            throw  e;
        }
    }

    public static boolean isContainChinese(String str) {
        Pattern p = Pattern.compile("[\u4e00-\u9fa5]");
        Matcher m = p.matcher(str);
        if (m.find()) {
            return true;
        }
        return false;
    }

    @Test
    @Description("正常测试用例：按中文类型搜索政策词典")
    @Story("政策词典")
    public void chineseSearchSuccess(){
        try{
            HashMap<String,Object> body=new HashMap<>();
            body.put("_file","/apijson/page/dictionaryPage/eweiShopQaQuestionFindConditions.json");
            body.put("conditionThree","chinese");
            Response response=dictionaryPage.findConditions(body);
            assertEquals((int) response.path("code"),200);
            assertEquals(response.path("message"),"操作成功");
            List<List<HashMap<String,String>>> title=response.path("data.children");
            title.forEach(list -> {
                list.forEach(map -> {
                    assertTrue(isContainChinese(map.get("title")) || map.get("title").matches(".*\\d.*"));
                });
            });
        }catch (AssertionError e){
            Reporter.log("DictionaryPageTest.chineseSearchSuccess：按中文类型搜索政策词典，断言失败！");
            throw  e;
        }
    }

    @Test
    @Description("正常测试用例：按英文类型搜索政策词典")
    @Story("政策词典")
    public void englishSearchSuccess(){
        try{
            HashMap<String,Object> body=new HashMap<>();
            body.put("_file","/apijson/page/dictionaryPage/eweiShopQaQuestionFindConditions.json");
            body.put("conditionThree","english");
            Response response=dictionaryPage.findConditions(body);
            assertEquals((int) response.path("code"),200);
            assertEquals(response.path("message"),"操作成功");
            List<List<HashMap<String,String>>> title=response.path("data.children");
            title.forEach(list -> {
                list.forEach(map -> {
                    assertTrue(map.get("title").matches(".*\\w.*"));
                });
            });
        }catch (AssertionError e){
            Reporter.log("DictionaryPageTest.englishSearchSuccess：按英文类型搜索政策词典，断言失败！");
            throw  e;
        }
    }

    @Test
    @Description("正常测试用例：组合搜索")
    @Story("政策词典")
    public void allKeySearchSuccess(){
        try{
            HashMap<String,Object> body=new HashMap<>();
            body.put("_file","/apijson/page/dictionaryPage/eweiShopQaQuestionFindConditions.json");
            body.put("conditionThree","chinese");
            Response response=dictionaryPage.findConditions(body);
            assertEquals((int) response.path("code"),200);
            assertEquals(response.path("message"),"操作成功");
            List<List<HashMap<String,String>>> title=response.path("data.children");
            title.forEach(list -> {
                list.forEach(map -> {
                    assertTrue(isContainChinese(map.get("title")) || map.get("title").matches(".*\\d.*"));
                });
            });
        }catch (AssertionError e){
            Reporter.log("DictionaryPageTest.allKeySearchSuccess：组合搜索，断言失败！");
            throw  e;
        }
    }

    @Test
    @Description("正常测试用例：获取词典详情信息")
    @Story("政策词典")
    public void getDictionaryInfoSuccess(){
        try{
            List<Object[]> sql= JDBCUtils.queryMulti("select id,title,content from ims_ewei_shop_qa_question limit 0,10;");
            HashMap<String,Object> body=new HashMap<>();
            body.put("_file","/apijson/page/dictionaryPage/eweiShopQaQuestionFindConditionsById.json");
            body.put("id",sql.get(0)[0]);
            Response response=dictionaryPage.getDictionaryInfo(body);
            assertEquals((int) response.path("code"),200);
            assertEquals(response.path("message"),"操作成功");
            HashMap<String,Object> title=response.path("data");
            assertEquals(title.get("title"),sql.get(0)[1]);
            String content=""+sql.get(0)[2];
            assertTrue(content.contains(""+title.get("content")));
        }catch (AssertionError e){
            Reporter.log("DictionaryPageTest.getDictionaryInfoSuccess：获取词典详情信息，断言失败！");
            throw  e;
        }
    }

    @Test
    @Description("正常测试用例：获取关联的政策")
    @Story("政策词典")
    public void getMoreDictionaryPolicySuccess(){
        try{
            HashMap<String,Object> body=new HashMap<>();
            body.put("_file","/apijson/page/dictionaryPage/eweiShopQaQuestionFindMorePolicy.json");
            Response response=dictionaryPage.getMoreDictionaryPolicy(body);
            assertEquals((int) response.path("code"),200);
            assertEquals(response.path("message"),"操作成功");
            List<HashMap<String,Object>> list=response.path("data");
            assertTrue(list.size()>0);
        }catch (AssertionError e){
            Reporter.log("DictionaryPageTest.getMoreDictionaryPolicySuccess：获取关联的政策，断言失败！");
            throw  e;
        }
    }
}