package page;

import conf.Config;
import io.qameta.allure.Description;
import io.qameta.allure.Story;
import io.restassured.response.Response;
import org.testng.Reporter;
import org.testng.annotations.Test;
import java.util.HashMap;
import java.util.List;

import static org.testng.Assert.*;

public class LoginPageTest {
    LoginPage loginPage=LoginPage.getInstance();
    Config config=Config.getInstance();

    @Test
    @Description("正常测试用例：正确的账密，登录成功")
    @Story("登录")
    public void passwordLoginSuccess(){
        try{
            HashMap<String,Object> body=new HashMap<>();
            body.put("_file","/apijson/page/loginPage/pcpLoginByType.json");
            body.put("username",config.username);
            body.put("password",config.password);
            Response response= loginPage.passwordLoginSuccess(body);
            assertEquals((int)response.path("code"),200);
            assertEquals(response.path("message"),"操作成功");
            String token=response.path("data.token");
            assertTrue(token.length()>0);
        }catch (AssertionError e){
            Reporter.log("LoginPageTest.passwordLoginSuccess：正确的账密，登录成功，断言失败！");
            throw  e;
        }
    }

    @Test
    @Description("异常测试用例：错误的账号，登录失败")
    @Story("登录")
    public void accountFailpasswordLoginFail(){
        try{
            HashMap<String,Object> body=new HashMap<>();
            body.put("_file","/apijson/page/loginPage/pcpLoginByType.json");
            body.put("username","15999999999");
            body.put("password",config.password);
            Response response= loginPage.passwordLoginSuccess(body);
            assertEquals((int)response.path("code"),400);
            assertEquals(response.path("message"),"用户不存在或已禁用");
            assertTrue(response.path("data")==null);
        }catch (AssertionError e){
            Reporter.log("LoginPageTest.accountFailpasswordLoginFail：错误的账号，登录失败，断言失败！");
            throw  e;
        }
    }


    @Test
    @Description("异常测试用例：账号为空，登录失败")
    @Story("登录")
    public void accountEmptyPasswordLoginFail(){
        try{
            HashMap<String,Object> body=new HashMap<>();
            body.put("_file","/apijson/page/loginPage/pcpLoginByType.json");
            body.put("username","");
            body.put("password",config.password);
            Response response= loginPage.passwordLoginSuccess(body);
            assertEquals((int)response.path("code"),400);
            assertEquals(response.path("message"),"用户名不能为空");
            assertTrue(response.path("data")==null);
        }catch (AssertionError e){
            Reporter.log("LoginPageTest.accountEmptyPasswordLoginFail：账号为空，登录失败，断言失败！");
            throw  e;
        }
    }

    @Test
    @Description("异常测试用例：密码错误，登录失败")
    @Story("登录")
    public void passwordFailPasswordLoginFail(){
        try{
            HashMap<String,Object> body=new HashMap<>();
            body.put("_file","/apijson/page/loginPage/pcpLoginByType.json");
            body.put("username",config.username);
            body.put("password","123");
            Response response= loginPage.passwordLoginSuccess(body);
            assertEquals((int)response.path("code"),400);
            assertEquals(response.path("message"),"用户名或密码错误");
            assertTrue(response.path("data")==null);
        }catch (AssertionError e){
            Reporter.log("LoginPageTest.passwordFailPasswordLoginFail：账号为空，登录失败，断言失败！");
            throw  e;
        }
    }

//    @Test
//    @Description("异常测试用例：密码为空，登录失败")
//    @Story("登录")
//    public void passwordEmptyPasswordLoginFail(){
//        HashMap<String,Object> body=new HashMap<>();
//        body.put("_file","/apijson/page/loginPage/pcpLoginByType.json");
//        body.put("username",config.username);
//        body.put("password","");
//        Response response= loginPage.passwordLoginSuccess(body);
//        assertEquals((int)response.path("code"),400);
//        assertEquals(response.path("message"),"用户名或密码错误");
//        assertTrue(response.path("data")==null);
//    }
}